//**************************************************************************//
//																			//
// File:		Initialisation.c											//
//																			//
// Project:		Example Host Loader File									//
//																			//
// Description: This file contains initialisation functions for the Target	//
//				DSP.														//
//																			//
//**************************************************************************//

#include "Example Host Loader File.h"

//--------------------------------------------------------------------------//
// Function:	Init_Interrupts												//
//																			//
// Parameters:	None														//
//																			//
// Return:		None														//
//																			//
// Description:	Configuration of interrupts for Host Port and Timer0.		//
//--------------------------------------------------------------------------//
void Init_Interrupts(void)
{
	// configure interrupt priorities
	sysreg_write(sysreg_IOPG, Interrupt_Controller_Page);
	io_space_write(IPR0, 0xbbb0);				// set all unused interrupts to lowest priority
	io_space_write(IPR1, 0xbbbb);
	io_space_write(IPR2, 0xbb4b);
	io_space_write(IPR3, 0xbbbb);

	// assign priorities to ISRs
	interrupt(SIG_INT4, HPI_ISR);				// HPI ISR gets interrupt priority 0
	interrupt(SIG_INT8, Timer0_ISR);			// Timer0 ISR gets interrupt priority 4
	enable_interrupts();
}

//--------------------------------------------------------------------------//
// Function:	Init_Timer0													//
//																			//
// Parameters:	None														//
//																			//
// Return:		None														//
//																			//
// Description:	Initialisation of Timer0 for a period of 100 ms and a width	//
//				of 50 ms (assuming 80 MHz HCLK).							//
//--------------------------------------------------------------------------//
void Init_Timer0(void)
{
	// configure Timer0
	sysreg_write(sysreg_IOPG, Timer_Page);
	io_space_write(CFGR0, 0x0019);				// PWM mode; enable interrupt
	io_space_write(PRDH0, 0x007a);				// set period high
	io_space_write(PRDL0, 0x1200);				// set period low
	io_space_write(WHR0, 0x003d);				// set width high
	io_space_write(WLR0, 0x0900);				// set width low
	io_space_write(GSR0, 0x0100);				// enable Timer0
}

//--------------------------------------------------------------------------//
// Function:	Init_Flags													//
//																			//
// Parameters:	None														//
//																			//
// Return:		None														//
//																			//
// Description:	Configuration of PF0 as output.								//
//--------------------------------------------------------------------------//
void Init_Flags(void)
{
	// set direction for general purpose flags
	sysreg_write(sysreg_IOPG, General_Purpose_IO);
	io_space_write(DIR, 0x0001);				// configure PF0 as output
}
